@@ -28,6 +28,9 @@
  *                 Derek J Smithies (derek@indranet.co.nz)
  *
  * $Log: main.h,v $
+ * Revision 1.104  2005/08/18 02:03:36  dereksmithies
+ * Remove sound card test option.. This will be installed in pwlib/samples/audio
+ *
  * Revision 1.103  2005/01/11 07:56:45  csoutheren
  * Added --number-prefix option
  * Fixed problem with using proxies
@@ -656,68 +659,6 @@ class TestUserInterfaceThread : public PThread
     MyH323EndPoint & endpoint;
 };
 
-/////////////////////////////////////////////////////////////////////////////
-PDECLARE_LIST(TestAudioDevice, PBYTEArray *)
-#if 0                                //This makes emacs bracket matching code happy.
-{
-#endif
- public:
-	virtual ~TestAudioDevice();
-
-	void Test();
-	BOOL DoEndNow();
-	BOOL DoStartNow();
-
-	void WriteAudioFrame(PBYTEArray *data);
-	PBYTEArray *GetNextAudioFrame();
-
-  protected:
-	PMutex access;
-	BOOL startNow;
-    BOOL endNow;
-};
-
-
-
-class TestAudio : public PObject  
-{
-	PCLASSINFO(TestAudio, PObject)
-public:
-	TestAudio(TestAudioDevice &master);
-	virtual ~TestAudio();
-
-	void LowerVolume();
-	void RaiseVolume();
-
-protected:
-	PString name;
-	void OpenAudio(enum PSoundChannel::Directions dir);
-
-	PINDEX             currentVolume;
-	TestAudioDevice    &controller;
-    PSoundChannel      sound;
-};
-
-class TestAudioRead : public PThread, public TestAudio
-{
-    PCLASSINFO(TestAudioRead, PThread);
-  public:
-	TestAudioRead(TestAudioDevice &master);
-
-	void Main();
-};
-
-
-class TestAudioWrite : public PThread, public TestAudio
-{
-    PCLASSINFO(TestAudioWrite, PThread);
-  public:
-	TestAudioWrite(TestAudioDevice &master);
-
-	void Main();
- };
-
-
 
 #endif  // _OhPhone_MAIN_H
 
