@@ -27,6 +27,16 @@
  * permission of the authors.
  *
  * $Log: xlibvid.cxx,v $
+ * Revision 1.20  2003/03/18 07:11:34  robertj
+ * Removed openh323 versions of videoio.h classes as PVideoOutputDevice
+ *   descendants for NULL and PPM files added to PWLib.
+ *
+ * Revision 1.19  2002/10/08 08:19:19  dereks
+ * Fix so compiles with gcc 3.2 (Redhat 8.0)
+ *
+ * Revision 1.18  2002/06/27 02:17:40  robertj
+ * Renamed video format 411 to the correct 420P, thanks Mark Cooke
+ *
  * Revision 1.17  2001/05/25 01:14:44  dereks
  * Alter SetFrameSize & OpenWindo to use unsigned variables. Change type of
  * other variables to eliminate compiler warnings.
@@ -170,6 +180,11 @@ GenericXlibVideoDevice::~GenericXlibVideoDevice()
   Close();
 }
 
+BOOL GenericXlibVideoDevice::Open(const PString &, BOOL)
+{
+	return TRUE;
+}
+
 BOOL GenericXlibVideoDevice::Close()
 {
        videoMutex.Wait();
@@ -180,6 +195,16 @@ BOOL GenericXlibVideoDevice::Close()
        return TRUE;
 }
 
+PStringList GenericXlibVideoDevice::GetDeviceNames() const
+{
+	return PStringList();
+}
+
+PINDEX GenericXlibVideoDevice::GetMaxFrameBytes()
+{
+	return 0;
+}
+
 BOOL GenericXlibVideoDevice::SetFrameSize (unsigned _width, unsigned _height)
 {
     videoMutex.Wait();
@@ -196,7 +221,7 @@ BOOL GenericXlibVideoDevice::SetFrameSize (unsigned _width, unsigned _height)
      return TRUE;
 }
 
-BOOL GenericXlibVideoDevice::OpenWindow(unsigned _width = 0, unsigned _height = 0)
+BOOL GenericXlibVideoDevice::OpenWindow(unsigned _width, unsigned _height)
 {
   PTRACE(3,"XDisplay\tOpenWindow of size "<<_width<<"x"<<_height<<
             " "<<DirectionStr()<<" window");
@@ -454,7 +479,7 @@ BOOL GenericXlibVideoDevice::DetermineVisualInformation(void)
 
 void GenericXlibVideoDevice::MaskCalc(int & startPos, int & looseNBits, int visualMask)
 {
-  /*The source data (from the YUV 411 image) is three bytes, one each for RGB.
+  /*The source data (from the YUV 420P image) is three bytes, one each for RGB.
     These three bytes have to be transformed into the N bit per pixel display.
     Some part of each of the three bytes will have to be lost.
    EG (abcd efgh)  (klmn opqr)  (stuv wxyz) are the three source RGB bytes.
@@ -574,7 +599,7 @@ void GenericXlibVideoDevice::AllocGrays(int num)
 
 #define LIMIT(x) (BYTE)(((x>0xffffff)?0xff0000:((x<=0xffff)?0:x&0xff0000))>>16)
 
-void GenericXlibVideoDevice::Translate411Input(BYTE *d, const void *frame)
+void GenericXlibVideoDevice::Translate420PInput(BYTE *d, const void *frame)
 {	
   const BYTE * yplane  = (const BYTE *) frame;
   const BYTE * yplane2 = yplane + width;
@@ -783,7 +808,10 @@ void GenericXlibVideoDevice::Translate411Input(BYTE *d, const void *frame)
   return;
 }
 
-BOOL GenericXlibVideoDevice::Redraw (const void *frame)
+BOOL GenericXlibVideoDevice::SetFrameData(unsigned x, unsigned y,
+			                  unsigned w, unsigned h,
+					  const BYTE * data,
+					  BOOL endFrame)
 {
   videoMutex.Wait();
   PTRACE(6,"XDisplay\t Redraw START "<<DirectionStr()<<" window.");
@@ -807,7 +835,7 @@ BOOL GenericXlibVideoDevice::Redraw (const void *frame)
 
   if(width&&height&&win[xIndex()]) {
      PTRACE(6,"XDisplay\t  Window all ready for "<<DirectionStr()<< " display");
-     Translate411Input(pixels[xIndex(useImage0)], frame);
+     Translate420PInput(pixels[xIndex(useImage0)], data);
      XImage * xi = images[xIndex(useImage0)];
      DisplayImage(xi);
      useImage0 = 1 - useImage0;
@@ -819,6 +847,12 @@ BOOL GenericXlibVideoDevice::Redraw (const void *frame)
 }
 
 
+BOOL GenericXlibVideoDevice::EndFrame()
+{
+  return TRUE;
+}
+
+
 BOOL  GenericXlibVideoDevice::IsOpen()
 {
   return nWindowsOpen > 0 ;
